==> zio-aws-kinesisanalyticsv2_3-5.17.157.1-sources.jar: zio/aws/kinesisanalyticsv2/model/ReferenceDataSourceUpdate.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.{InAppTableName, Id}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ReferenceDataSourceUpdate(
    referenceId: Id,
    tableNameUpdate: Option[InAppTableName] = None,
    s3ReferenceDataSourceUpdate: Option[
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate
    ] = None,
    referenceSchemaUpdate: Option[
      zio.aws.kinesisanalyticsv2.model.SourceSchema
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate = {
    import ReferenceDataSourceUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
      .builder()
      .referenceId(Id.unwrap(referenceId): java.lang.String)
      .optionallyWith(
        tableNameUpdate.map(value =>
          InAppTableName.unwrap(value): java.lang.String
        )
      )(_.tableNameUpdate)
      .optionallyWith(
        s3ReferenceDataSourceUpdate.map(value => value.buildAwsValue())
      )(_.s3ReferenceDataSourceUpdate)
      .optionallyWith(
        referenceSchemaUpdate.map(value => value.buildAwsValue())
      )(_.referenceSchemaUpdate)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
      .wrap(buildAwsValue())
}
object ReferenceDataSourceUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate =
      zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate(
        referenceId,
        tableNameUpdate.map(value => value),
        s3ReferenceDataSourceUpdate.map(value => value.asEditable),
        referenceSchemaUpdate.map(value => value.asEditable)
      )
    def referenceId: Id
    def tableNameUpdate: Option[InAppTableName]
    def s3ReferenceDataSourceUpdate: Option[
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.ReadOnly
    ]
    def referenceSchemaUpdate
        : Option[zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly]
    def getReferenceId: ZIO[Any, Nothing, Id] = ZIO.succeed(referenceId)
    def getTableNameUpdate: ZIO[Any, AwsError, InAppTableName] =
      AwsError.unwrapOptionField("tableNameUpdate", tableNameUpdate)
    def getS3ReferenceDataSourceUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.ReadOnly
    ] = AwsError.unwrapOptionField(
      "s3ReferenceDataSourceUpdate",
      s3ReferenceDataSourceUpdate
    )
    def getReferenceSchemaUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly
    ] =
      AwsError.unwrapOptionField("referenceSchemaUpdate", referenceSchemaUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
  ) extends zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate.ReadOnly {
    override val referenceId: Id =
      zio.aws.kinesisanalyticsv2.model.primitives.Id(impl.referenceId())
    override val tableNameUpdate: Option[InAppTableName] = scala
      .Option(impl.tableNameUpdate())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.primitives.InAppTableName(value)
      )
    override val s3ReferenceDataSourceUpdate: Option[
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.ReadOnly
    ] = scala
      .Option(impl.s3ReferenceDataSourceUpdate())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.wrap(value)
      )
    override val referenceSchemaUpdate
        : Option[zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly] = scala
      .Option(impl.referenceSchemaUpdate())
      .map(value => zio.aws.kinesisanalyticsv2.model.SourceSchema.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
  ): zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalyticsv2_3-7.21.15.8-sources.jar: zio/aws/kinesisanalyticsv2/model/ReferenceDataSourceUpdate.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.{InAppTableName, Id}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ReferenceDataSourceUpdate(
    referenceId: Id,
    tableNameUpdate: Optional[InAppTableName] = Optional.Absent,
    s3ReferenceDataSourceUpdate: Optional[
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate
    ] = Optional.Absent,
    referenceSchemaUpdate: Optional[
      zio.aws.kinesisanalyticsv2.model.SourceSchema
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate = {
    import ReferenceDataSourceUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
      .builder()
      .referenceId(Id.unwrap(referenceId): java.lang.String)
      .optionallyWith(
        tableNameUpdate.map(value =>
          InAppTableName.unwrap(value): java.lang.String
        )
      )(_.tableNameUpdate)
      .optionallyWith(
        s3ReferenceDataSourceUpdate.map(value => value.buildAwsValue())
      )(_.s3ReferenceDataSourceUpdate)
      .optionallyWith(
        referenceSchemaUpdate.map(value => value.buildAwsValue())
      )(_.referenceSchemaUpdate)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
      .wrap(buildAwsValue())
}
object ReferenceDataSourceUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate =
      zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate(
        referenceId,
        tableNameUpdate.map(value => value),
        s3ReferenceDataSourceUpdate.map(value => value.asEditable),
        referenceSchemaUpdate.map(value => value.asEditable)
      )
    def referenceId: Id
    def tableNameUpdate: Optional[InAppTableName]
    def s3ReferenceDataSourceUpdate: Optional[
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.ReadOnly
    ]
    def referenceSchemaUpdate
        : Optional[zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly]
    def getReferenceId: ZIO[Any, Nothing, Id] = ZIO.succeed(referenceId)
    def getTableNameUpdate: ZIO[Any, AwsError, InAppTableName] =
      AwsError.unwrapOptionField("tableNameUpdate", tableNameUpdate)
    def getS3ReferenceDataSourceUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.ReadOnly
    ] = AwsError.unwrapOptionField(
      "s3ReferenceDataSourceUpdate",
      s3ReferenceDataSourceUpdate
    )
    def getReferenceSchemaUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly
    ] =
      AwsError.unwrapOptionField("referenceSchemaUpdate", referenceSchemaUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
  ) extends zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate.ReadOnly {
    override val referenceId: Id =
      zio.aws.kinesisanalyticsv2.model.primitives.Id(impl.referenceId())
    override val tableNameUpdate: Optional[InAppTableName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tableNameUpdate())
        .map(value =>
          zio.aws.kinesisanalyticsv2.model.primitives.InAppTableName(value)
        )
    override val s3ReferenceDataSourceUpdate: Optional[
      zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.s3ReferenceDataSourceUpdate())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.S3ReferenceDataSourceUpdate.wrap(value)
      )
    override val referenceSchemaUpdate
        : Optional[zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.referenceSchemaUpdate())
        .map(value => zio.aws.kinesisanalyticsv2.model.SourceSchema.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ReferenceDataSourceUpdate
  ): zio.aws.kinesisanalyticsv2.model.ReferenceDataSourceUpdate.ReadOnly =
    new Wrapper(impl)
}
